@@ -1,5 +1,5 @@
 package WebService::Gitter;
-$WebService::Gitter::VERSION = '2.0.0';
+$WebService::Gitter::VERSION = '2.1.0';
 #ABSTRACT: An interface to Gitter REST API via Perl 5.
 
 use strict;
@@ -61,6 +61,18 @@ method remove_user_from_room( $room_id, $user_id ) {
 }
 
 
+method update_room( $room_id,
+    : $topic   = '',
+    : $noindex = 'false',
+    : $tags    = '' )
+{
+    return $self->put(
+        "/rooms/$room_id?access_token=" . $self->api_key,
+        { topic => $topic, noindex => $noindex, tags => $tags }
+    );
+}
+
+
 method delete_room($room_id) {
     return $self->delete( "/rooms/$room_id?access_token=" . $self->api_key );
 }
@@ -136,7 +148,7 @@ WebService::Gitter - An interface to Gitter REST API via Perl 5.
 
 =head1 VERSION
 
-version 2.0.0
+version 2.1.0
 
 =head1 SYNOPSIS
 
@@ -168,6 +180,9 @@ version 2.0.0
     # Leave/remove user from a room.
     $git->remove_user_from_room($room_id, $user_id);
     
+    # Update room.
+    update_room($room_id, topic => $topic, noindex => $noindex, tags => $tags);
+    
     # Delete room.
     $git->delete_room($room_id);
 
@@ -188,6 +203,10 @@ version 2.0.0
     # Update message/text in a room.
     $git->update_message($room_id, $message_id, text => $new_text);
 
+=head1 NOTE
+
+This module does not support Faye endpoint and streaming API..yet. Currently as of writing this, the Gitter's API is still in beta and likely to break backward compatibility in the future.
+
 =head2 Methods
 
 =over 4
@@ -277,6 +296,24 @@ Returns: Remove user from a room response message.
 
 =over 4
 
+=item update_room($room_id, topic => $topic, noindex => $noindex, tags => $tags)
+
+Description: Update room.
+
+Parameter: B<REQUIRED>C<$room_id> - Room ID.
+
+Parameter: B<OPTIONAL>C<$topic> - Room topic.
+
+Parameter: B<OPTIONAL>C<$noindex> - (false, true) Whether the room is indexed by search engines.
+
+Parameter: B<OPTIONAL>C<$tags> - 'tag1, tag2, etc' Tags that define the room.
+
+Returns: Update room response message.
+
+=back
+
+=over 4
+
 =item delete_room($room_id)
 
 Description: Delete room.
@@ -397,7 +434,7 @@ This software is Copyright (c) 2017-2018 by faraco.
 
 This is free software, licensed under:
 
-  The GNU General Public License, Version 3, June 2007
+  The MIT (X11) License
 
 =cut
 
